@@ -26,9 +26,14 @@ function [w] = barthannwin(L)
     error("L must be a positive integer");
   endif
   L = round(L);
-  N = L-1;
-  n = 0:N;
 
-  w = 0.62 -0.48.*abs(n./(L-1) - 0.5)+0.38*cos(2.*pi*(n./(L-1)-0.5));
-  w = w';
+  if (L == 1)
+    w = 1;
+  else
+    N = L-1;
+    n = 0:N;
+
+    w = 0.62 -0.48.*abs(n./(L-1) - 0.5)+0.38*cos(2.*pi*(n./(L-1)-0.5));
+    w = w';
+  endif
 endfunction
