@@ -13,7 +13,7 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
-## b = firls(N, F, A);
+## b = firls(N, F, A); 
 ## b = firls(N, F, A, W);
 ##
 ##  FIR filter design using least squares method. Returns a length N+1
@@ -28,7 +28,8 @@
 ##
 ##  W is an optional weighting function that contains one value for each
 ##  band that weights the mean squared error in that band. A must be the
-##  same length as F, and W must be half the length of F.
+##  same length as F, and W must be half the length of F. N must be
+##  even. If given an odd value, firls increments it by 1.
 ##
 ## The least squares optimization algorithm for computing FIR filter
 ## coefficients is derived in detail in:
@@ -38,32 +39,34 @@
 
 function coef = firls(N, frequencies, pass, weight, str);
 
-  if nargin<3 || nargin>6
+  if (nargin < 3 || nargin > 6)
     print_usage;
-  elseif nargin==3
-    weight = ones(1, length(pass)/2);
+  elseif (nargin == 3)
+    weight = ones (1, length(pass)/2);
     str = [];
-  elseif nargin==4
-    if ischar(weight)
+  elseif (nargin == 4)
+    if ischar (weight)
       str = weight;
       weight = ones (size (pass));
     else
       str = [];
-    end
-  end
+    endif
+  endif
   if length (frequencies) ~= length (pass)
     error("F and A must have equal lengths.");
   elseif 2 * length (weight) ~= length (pass)
     error("W must contain one weight per band.");
-  elseif ischar(str)
+  elseif ischar (str)
     error("This feature is implemented yet");
   else
 
+    N += mod (N, 2);
+
     M = N/2;
-    w = kron(weight(:), [-1; 1]);
+    w = kron (weight(:), [-1; 1]);
     omega = frequencies * pi;
-    i1 = 1:2:length(omega);
-    i2 = 2:2:length(omega);
+    i1 = 1:2:length (omega);
+    i2 = 2:2:length (omega);
 
     ## Generate the matrix Q
     ## As illustrated in the above-cited reference, the matrix can be
@@ -94,8 +97,8 @@ function coef = firls(N, frequencies, pass, weight, str);
     ## -                             n
     ##
     cos_ints2 = [omega(i1).^2 - omega(i2).^2; ...
-		 cos((1:M)' * omega(i2)) - cos((1:M)' * omega(i1))] ./ ...
-                 ([2, 1:M]' * (omega(i2) - omega(i1)));
+		             cos((1:M)' * omega(i2)) - cos((1:M)' * omega(i1))] ./ ...
+        ([2, 1:M]' * (omega(i2) - omega(i1)));
     d = [-weight .* pass(i1); weight .* pass(i2)] (:);
     b = [1, 1./(1:M)]' .* ((kron (cos_ints2, [1, 1]) + cos_ints(1:M+1,:)) * d);
 
@@ -104,6 +107,6 @@ function coef = firls(N, frequencies, pass, weight, str);
     a = Q \ b;
     coef = [ a(end:-1:2); 2 * a(1); a(2:end) ];
 
-  end
+  endif
 
 endfunction
