@@ -36,13 +36,13 @@
 ## S -> C Fc/S       pole: 0                    zero: 0
 ##                   gain: -x                   gain: -1/x
 ## ----------------  -------------------------  ------------------------
-## Band Pass         zero: b  sqrt(b^2-FhFl)   pole: b  sqrt(b^2-FhFl)
+## Band Pass         zero: b ± sqrt(b^2-FhFl)   pole: b ± sqrt(b^2-FhFl)
 ##        S^2+FhFl   pole: 0                    zero: 0
 ## S -> C --------   gain: C/(Fh-Fl)            gain: (Fh-Fl)/C
 ##        S(Fh-Fl)   b=x/C (Fh-Fl)/2            b=x/C (Fh-Fl)/2
 ## ----------------  -------------------------  ------------------------
-## Band Stop         zero: b  sqrt(b^2-FhFl)   pole: b  sqrt(b^2-FhFl)
-##        S(Fh-Fl)   pole: sqrt(-FhFl)         zero: sqrt(-FhFl)
+## Band Stop         zero: b ± sqrt(b^2-FhFl)   pole: b ± sqrt(b^2-FhFl)
+##        S(Fh-Fl)   pole: ±sqrt(-FhFl)         zero: ±sqrt(-FhFl)
 ## S -> C --------   gain: -x                   gain: -1/x
 ##        S^2+FhFl   b=C/x (Fh-Fl)/2            b=C/x (Fh-Fl)/2
 ## ----------------  -------------------------  ------------------------
@@ -102,8 +102,8 @@ function [Sz, Sp, Sg] = sftrans(Sz, Sp, Sg, W, stop)
     Fh = W(2);
     if stop
 ## ----------------  -------------------------  ------------------------
-## Band Stop         zero: b  sqrt(b^2-FhFl)   pole: b  sqrt(b^2-FhFl)
-##        S(Fh-Fl)   pole: sqrt(-FhFl)         zero: sqrt(-FhFl)
+## Band Stop         zero: b ± sqrt(b^2-FhFl)   pole: b ± sqrt(b^2-FhFl)
+##        S(Fh-Fl)   pole: ±sqrt(-FhFl)         zero: ±sqrt(-FhFl)
 ## S -> C --------   gain: -x                   gain: -1/x
 ##        S^2+FhFl   b=C/x (Fh-Fl)/2            b=C/x (Fh-Fl)/2
 ## ----------------  -------------------------  ------------------------
@@ -128,7 +128,7 @@ function [Sz, Sp, Sg] = sftrans(Sz, Sp, Sg, W, stop)
       end
     else
 ## ----------------  -------------------------  ------------------------
-## Band Pass         zero: b  sqrt(b^2-FhFl)   pole: b  sqrt(b^2-FhFl)
+## Band Pass         zero: b ± sqrt(b^2-FhFl)   pole: b ± sqrt(b^2-FhFl)
 ##        S^2+FhFl   pole: 0                    zero: 0
 ## S -> C --------   gain: C/(Fh-Fl)            gain: (Fh-Fl)/C
 ##        S(Fh-Fl)   b=x/C (Fh-Fl)/2            b=x/C (Fh-Fl)/2
