@@ -14,7 +14,7 @@
 %% this program; if not, see <http://www.gnu.org/licenses/>.
 
 %% Usage:
-%%   [Pxx,freq]=tfestimate(x,y,Nfft,Fs,window,overlap,range,plot_type,detrend)
+%%   [Pxx,freq]=tfestimate(x,y,window,overlap,Nfft,Fs,range)
 %%
 %%     Estimate transfer function of system with input "x" and output "y".
 %%     Use the Welch (1967) periodogram/FFT method.
@@ -23,8 +23,8 @@
 function [varargout] = tfestimate(varargin)
   %%
   %% Check fixed argument
-  if ( nargin<2 )
-    error( 'tfestimate: Need at least 2 args. Use help tfestimate' );
+  if (nargin < 2 || nargin > 7)
+    print_usage ();
   end
   nvarargin = length(varargin);
   %% remove any pwelch RESULT args and add 'cross'
