@@ -1,32 +1,18 @@
-/*
-
-Copyright (c) 2008-2009, Evgeni A. Nurminski <nurmi@dvo.ru>
-Copyright (c) 2008-2009, Pete Gonzalez <pgonzalez@bluel.com>
-
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-
-Authors:
-
-Evgeni A. Nurminski <nurmi@dvo.ru>
-Institute for Automation and Control Problems
-Far East branch of RAS, Vladivostok, Russia
-
-Pete Gonzalez <pgonzalez@bluel.com>
-Bluel Technologies Corporation
-
-*/
+// Copyright (c) 2008-2009, Evgeni A. Nurminski <nurmi@dvo.ru>
+// Copyright (c) 2008-2009, Pete Gonzalez <pgonzalez@bluel.com>
+//
+// This program is free software; you can redistribute it and/or modify it under
+// the terms of the GNU General Public License as published by the Free Software
+// Foundation; either version 3 of the License, or (at your option) any later
+// version.
+//
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+// details.
+//
+// You should have received a copy of the GNU General Public License along with
+// this program; if not, see <http://www.gnu.org/licenses/>.
 
 #ifdef _MSC_VER
 #define _CRT_SECURE_NO_WARNINGS  // disable spurious warnings
